kopuz-components 0.7.0

A modern, lightweight music player built with Rust and Dioxus.
docs.rs failed to build kopuz-components-0.7.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Reusable Dioxus UI components for the Kopuz music player: modern/normal list views, navigation controller, titlebar, sidebar, bottombar, and shared UI primitives.