logo
pub struct Compound { /* private fields */ }
Compound schemes (aka Split Complementary) are almost the same as complementary schemes.

Instead of using colors that are opposites, it uses colors on both sides of the opposite hue

Implementations

Generate Compound scheme with your color

Retrieve count colors of scheme

Set color by index

Retrieve primary color of scheme

Set the primary color of scheme