Struct components::foundation::properties::ListProperties
source · [−]pub struct ListProperties {}Fields
key: KeyThe key to identify widget
x: f32The control x position, relative to its container
y: f32The control y position, relative to its container
w: f32The control width
h: f32The control height
w_min: f32The control minimum width
h_min: f32The control minimum height
w_max: f32The control maximum width
h_max: f32The control maximum height
parent: Option<Id>The control parent, if any
depth: f32The control depth. Usually set internally
visible: boolWhether or not the control is visible at creation
mouse_input: boolWhether or not the control responds to mouse input
key_input: boolWhether or not the control responds to key input
renderable: boolWhether or not the control emits render signals from the canvas render call
internal_visible: boolInternal. Internal parent visibility for creating sub controls.