Enum components::winit::event::DeviceEvent
[−]pub enum DeviceEvent {
Added,
Removed,
MouseMotion {
delta: (f64, f64),
},
MouseWheel {
delta: MouseScrollDelta,
},
Motion {
axis: u32,
value: f64,
},
Button {
button: u32,
state: ElementState,
},
Key(KeyboardInput),
Text {
codepoint: char,
},
}Expand description
Represents raw hardware events that are not associated with any particular window.
Useful for interactions that diverge significantly from a conventional 2D GUI, such as 3D camera or first-person game controls. Many physical actions, such as mouse movement, can produce both device and window events. Because window events typically arise from virtual devices (corresponding to GUI cursors and keyboard focus) the device IDs may not match.
Note that these events are delivered regardless of input focus.
Variants
Added
Removed
MouseMotion
Fields
Change in physical position of a pointing device.
This represents raw, unfiltered physical motion. Not to be confused with WindowEvent::CursorMoved.
MouseWheel
Fields
delta: MouseScrollDeltaPhysical scroll event
Motion
Motion on some analog axis. This event will be reported for all arbitrary input devices that winit supports on this platform, including mouse devices. If the device is a mouse device then this will be reported alongside the MouseMotion event.
Button
Key(KeyboardInput)
Text
Fields
codepoint: charTrait Implementations
impl Clone for DeviceEvent
impl Clone for DeviceEvent
fn clone(&self) -> DeviceEvent
fn clone(&self) -> DeviceEvent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
impl Debug for DeviceEvent
impl Debug for DeviceEvent
impl PartialEq<DeviceEvent> for DeviceEvent
impl PartialEq<DeviceEvent> for DeviceEvent
fn eq(&self, other: &DeviceEvent) -> bool
fn eq(&self, other: &DeviceEvent) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &DeviceEvent) -> bool
fn ne(&self, other: &DeviceEvent) -> bool
This method tests for !=.
impl StructuralPartialEq for DeviceEvent