Struct components::foundation::colorschemes::Compound
[−]pub struct Compound { /* private fields */ }Expand description
Compound schemes (aka Split Complementary) are almost the same as complementary schemes.
Instead of using colors that are opposites, it uses colors on both sides of the opposite hue
Implementations
impl Compound
impl Compound
pub fn num_of_colors(&self) -> usize
pub fn num_of_colors(&self) -> usize
Retrieve count colors of scheme
pub fn primary_color(&self) -> Color
pub fn primary_color(&self) -> Color
Retrieve primary color of scheme
pub fn set_primary_color(&mut self, val: Color)
pub fn set_primary_color(&mut self, val: Color)
Set the primary color of scheme